[][src]Struct ic_utils::call::AndThenAsyncCaller

pub struct AndThenAsyncCaller<Out: for<'de> ArgumentDecoder<'de> + Send + Sync, Out2: for<'de> ArgumentDecoder<'de> + Send + Sync, Inner: AsyncCall<Out> + Sync + Send, R: Future<Output = Result<Out2, AgentError>> + Send + Sync, AndThen: Sync + Send + Fn(Out) -> R> { /* fields omitted */ }

An AsyncCall that applies a transform function to the result of the call. Because of constraints on the type system in Rust, both the input and output to the function must be deserializable.

Implementations

impl<Out, Out2, Inner, R, AndThen> AndThenAsyncCaller<Out, Out2, Inner, R, AndThen> where
    Out: for<'de> ArgumentDecoder<'de> + Send + Sync,
    Out2: for<'de> ArgumentDecoder<'de> + Send + Sync,
    Inner: AsyncCall<Out> + Sync + Send,
    R: Future<Output = Result<Out2, AgentError>> + Send + Sync,
    AndThen: Sync + Send + Fn(Out) -> R, 
[src]

pub fn new(inner: Inner, and_then: AndThen) -> Self[src]

pub async fn call(self) -> Result<RequestId, AgentError>[src]

pub async fn call_and_wait<W>(self, waiter: W) -> Result<Out2, AgentError> where
    W: Waiter
[src]

pub fn and_then<Out3, R2, AndThen2>(
    self,
    and_then: AndThen2
) -> AndThenAsyncCaller<Out2, Out3, Self, R2, AndThen2> where
    Out3: for<'de> ArgumentDecoder<'de> + Send + Sync,
    R2: Future<Output = Result<Out3, AgentError>> + Send + Sync,
    AndThen2: Sync + Send + Fn(Out2) -> R2, 
[src]

pub fn map<Out3, Map>(
    self,
    map: Map
) -> MappedAsyncCaller<Out2, Out3, Self, Map> where
    Out3: for<'de> ArgumentDecoder<'de> + Send + Sync,
    Map: Sync + Send + Fn(Out2) -> Out3, 
[src]