Struct ic_utils::call::AsyncCaller[][src]

pub struct AsyncCaller<'agent, Out> where
    Out: for<'de> ArgumentDecoder<'de> + Send + Sync
{ /* fields omitted */ }

An async caller, encapsulating a call to an update method.

Implementations

impl<'agent, Out> AsyncCaller<'agent, Out> where
    Out: for<'de> ArgumentDecoder<'de> + Send + Sync
[src]

pub fn build_call(self) -> Result<UpdateBuilder<'agent>, AgentError>[src]

Build an UpdateBuilder call that can be used directly with the Agent. This is essentially downleveling this type into the lower level [ic-agent] abstraction.

pub async fn call(self) -> Result<RequestId, AgentError>[src]

Perform this call and returns .

pub async fn call_and_wait<W>(self, waiter: W) -> Result<Out, AgentError> where
    W: Waiter
[src]

pub async fn call_and_wait_one<W, T>(self, waiter: W) -> Result<T, AgentError> where
    W: Waiter,
    T: DeserializeOwned
[src]

pub fn map<Out2, Map>(self, map: Map) -> MappedAsyncCaller<Out, Out2, Self, Map> where
    Out2: for<'de> ArgumentDecoder<'de> + Send + Sync,
    Map: Sync + Send + Fn(Out) -> Out2, 
[src]