Struct ic_utils::call::MappedAsyncCaller[][src]

pub struct MappedAsyncCaller<Out: for<'de> ArgumentDecoder<'de> + Send, Out2: for<'de> ArgumentDecoder<'de> + Send, Inner: AsyncCall<Out> + Send, Map: Send + Fn(Out) -> Out2> { /* fields omitted */ }

A structure that applies a transform function to the result of a call. Because of constraints on the type system in Rust, both the input and output to the function must be deserializable.

Implementations

impl<Out, Out2, Inner, Map> MappedAsyncCaller<Out, Out2, Inner, Map> where
    Out: for<'de> ArgumentDecoder<'de> + Send,
    Out2: for<'de> ArgumentDecoder<'de> + Send,
    Inner: AsyncCall<Out> + Send,
    Map: Send + Fn(Out) -> Out2, 
[src]

pub fn new(inner: Inner, map: Map) -> Self[src]

pub async fn call(self) -> Result<RequestId, AgentError>[src]

pub async fn call_and_wait<W>(self, waiter: W) -> Result<Out2, AgentError> where
    W: Waiter
[src]

pub fn and_then<Out3, R2, AndThen2>(
    self,
    and_then: AndThen2
) -> AndThenAsyncCaller<Out2, Out3, Self, R2, AndThen2> where
    Out3: for<'de> ArgumentDecoder<'de> + Send,
    R2: Future<Output = Result<Out3, AgentError>> + Send,
    AndThen2: Send + Fn(Out2) -> R2, 
[src]

pub fn map<Out3, Map2>(
    self,
    map: Map2
) -> MappedAsyncCaller<Out2, Out3, Self, Map2> where
    Out3: for<'de> ArgumentDecoder<'de> + Send,
    Map2: Send + Fn(Out2) -> Out3, 
[src]