pub struct SyncCaller<'agent, Out> where
Out: for<'de> ArgumentDecoder<'de> + Send, { /* fields omitted */ }
A synchronous call encapsulation.
Execute the call, returning either the value returned by the canister, or an
error returned by the Agent. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.
impl<V, T> VZip<V> for T where
V: MultiLane<T>,