Module canister

Module canister 

A higher-level canister type for managing various aspects of a canister.

Structs

Argument
A buffer to hold canister argument blob.
AsyncCallBuilder
A builder for an asynchronous call (ie. update) to the Internet Computer.
Canister
Create an encapsulation of a Canister running on the Internet Computer. This supports making calls to methods, installing code if needed, and various utilities related to a canister.
CanisterBuilder
A canister builder, which can be used to create a canister abstraction.
SyncCallBuilder
A builder for a synchronous call (ie. query) to the Internet Computer.

Enums

CanisterBuilderError
An error happened while building a canister.