[−][src]Struct ic_utils::canister::Argument
Implementations
impl Argument[src]
pub fn push_idl_arg<A: CandidType>(&mut self, arg: A)[src]
Add an IDL Argument. If the current value of Argument is Raw, will set the result to an error. If the current value is an error, will do nothing.
pub fn set_raw_arg(&mut self, arg: Vec<u8>)[src]
Set the argument as raw, replacing any value that was there before. If the current argument was an error, does nothing.
pub fn serialize(self) -> Result<Vec<u8>, AgentError>[src]
pub fn reset(&mut self)[src]