Struct ic_utils::interfaces::http_request::HttpRequestCanister[][src]

pub struct HttpRequestCanister;

Implementations

impl HttpRequestCanister[src]

pub fn create(
    agent: &Agent,
    canister_id: Principal
) -> Canister<'_, HttpRequestCanister>
[src]

Create an instance of a Canister implementing the HttpRequestCanister interface and pointing to the right Canister ID.

pub fn with_agent(agent: &Agent) -> CanisterBuilder<'_, HttpRequestCanister>[src]

Creating a CanisterBuilder with the right interface and Canister Id. This can be useful, for example, for providing additional Builder information.