pub enum ComputeAllocationError {
MustBeAPercentage(),
}Expand description
An error encountered when attempting to construct a ComputeAllocation.
Variants
MustBeAPercentage()
The provided value was not a percentage in the range [0, 100].