FreezingThreshold

Struct FreezingThreshold 

pub struct FreezingThreshold(/* private fields */);
A freezing threshold for a canister. Can be anywhere from 0 to 2^64-1 inclusive.

This represents the time, in seconds, of ‘runway’ the IC tries to guarantee the canister. If the canister’s persistent costs, like storage, will likely lead it to run out of cycles within this amount of time, then the IC will ‘freeze’ the canister. Attempts to call its methods will be rejected unconditionally. The canister also cannot make any calls that push its cycle count into freezing threshold range.