Struct ic_utils::interfaces::management_canister::InstallCodeBuilder[][src]

pub struct InstallCodeBuilder<'agent, 'canister: 'agent, T> { /* fields omitted */ }

Implementations

impl<'agent, 'canister: 'agent, T> InstallCodeBuilder<'agent, 'canister, T>[src]

pub fn builder(
    canister: &'canister Canister<'agent, T>,
    canister_id: &Principal,
    wasm: &'canister [u8]
) -> Self
[src]

Create an InstallCode builder, which is also an AsyncCall implementation.

pub fn with_arg<Argument: CandidType + Sync + Send>(
    self,
    arg: Argument
) -> InstallCodeBuilder<'agent, 'canister, T>
[src]

Add an argument to the installation, which will be passed to the init method of the canister.

pub fn with_raw_arg(
    self,
    arg: Vec<u8>
) -> InstallCodeBuilder<'agent, 'canister, T>
[src]

Override the argument passed in to the canister with raw bytes.

pub fn with_mode(self, mode: InstallMode) -> Self[src]

Pass in the InstallMode.

pub fn with_optional_compute_allocation<C, E>(
    self,
    compute_allocation: Option<C>
) -> Self where
    E: Display,
    C: TryInto<ComputeAllocation, Error = E>, 
[src]

Pass in a compute allocation optional value for the canister. If this is None, it will revert the compute allocation to default.

pub fn with_compute_allocation<C, E>(self, compute_allocation: C) -> Self where
    E: Display,
    C: TryInto<ComputeAllocation, Error = E>, 
[src]

Pass in a compute allocation value for the canister.

pub fn with_optional_memory_allocation<E, C>(
    self,
    memory_allocation: Option<C>
) -> Self where
    E: Display,
    C: TryInto<MemoryAllocation, Error = E>, 
[src]

Pass in a memory allocation optional value for the canister. If this is None, it will revert the memory allocation to default.

pub fn with_memory_allocation<C, E>(self, memory_allocation: C) -> Self where
    E: Display,
    C: TryInto<MemoryAllocation, Error = E>, 
[src]

Pass in a memory allocation value for the canister.

pub fn build(self) -> Result<impl 'agent + AsyncCall<()>, AgentError>[src]

Create an AsyncCall implementation that, when called, will install the canister.

pub async fn call(self) -> Result<RequestId, AgentError>[src]

Make a call. This is equivalent to the AsyncCall::call.

pub async fn call_and_wait<W>(self, waiter: W) -> Result<(), AgentError> where
    W: Waiter
[src]

Make a call. This is equivalent to the AsyncCall::call_and_wait.