RenameToRecord

Struct RenameToRecord 

pub struct RenameToRecord {
    pub canister_id: Principal,
    pub version: u64,
    pub total_num_changes: u64,
}
Rename To Record

Details about the new canister ID in a rename operation.

Contains the canister ID, version, and total number of changes of the new canister ID. After renaming, the total number of canister changes reported by the IC method canister_info is overridden to this value.

See RenameCanisterRecord::rename_to.

Fields

canister_id: Principal

The new canister ID.

version: u64

The version of the new canister.

total_num_changes: u64

The total number of changes in the new canister’s history. This value overrides the total reported by canister_info after renaming.