Struct ic_utils::interfaces::management_canister::StatusCallResult [−][src]
pub struct StatusCallResult {
pub status: CanisterStatus,
pub settings: DefiniteCanisterSettings,
pub module_hash: Option<Vec<u8>>,
pub memory_size: Nat,
pub cycles: Nat,
}Expand description
The complete canister status information of a canister. This includes the CanisterStatus, a hash of the module installed on the canister (None if nothing installed), the contoller of the canister, the canisters memory size, and its balance in cycles.
Fields
status: CanisterStatussettings: DefiniteCanisterSettingsmodule_hash: Option<Vec<u8>>memory_size: Natcycles: NatTrait Implementations
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]Deserialize this value from the given Serde deserializer. Read more