UpdateSettingsBuilder

Struct UpdateSettingsBuilder 

pub struct UpdateSettingsBuilder<'agent, 'canister: 'agent> { /* private fields */ }
A builder for an update_settings call.

Implementations

Source

impl<'agent, 'canister: 'agent> UpdateSettingsBuilder<'agent, 'canister>

pub fn builder( canister: &'canister Canister<'agent>, canister_id: &Principal, ) -> Self

Create an UpdateCanister builder, which is also an AsyncCall implementation.

pub fn with_controller<C, E>(self, controller: C) -> Self
where E: Display, C: TryInto<Principal, Error = E>,

Pass in a controller for the canister. Can be called multiple times to add multiple controllers.

pub fn with_compute_allocation<C, E>(self, compute_allocation: C) -> Self
where E: Display, C: TryInto<ComputeAllocation, Error = E>,

Pass in a compute allocation value for the canister.

pub fn with_memory_allocation<C, E>(self, memory_allocation: C) -> Self
where E: Display, C: TryInto<MemoryAllocation, Error = E>,

Pass in a memory allocation value for the canister.

pub fn with_freezing_threshold<C, E>(self, freezing_threshold: C) -> Self
where E: Display, C: TryInto<FreezingThreshold, Error = E>,

Pass in a freezing threshold value for the canister.

pub fn with_reserved_cycles_limit<C, E>(self, limit: C) -> Self
where E: Display, C: TryInto<ReservedCyclesLimit, Error = E>,

Pass in a reserved cycles limit value for the canister.

pub fn with_wasm_memory_limit<C, E>(self, wasm_memory_limit: C) -> Self
where E: Display, C: TryInto<WasmMemoryLimit, Error = E>,

Pass in a Wasm memory limit value for the canister.

pub fn with_wasm_memory_threshold<C, E>(self, wasm_memory_threshold: C) -> Self
where E: Display, C: TryInto<WasmMemoryLimit, Error = E>,

Pass in a Wasm memory threshold value for the canister.

pub fn with_log_memory_limit<C, E>(self, log_memory_limit: C) -> Self
where E: Display, C: TryInto<LogMemoryLimit, Error = E>,

Pass in a log memory limit value for the canister.

pub fn with_log_visibility<C, E>(self, log_visibility: C) -> Self
where E: Display, C: TryInto<LogVisibility, Error = E>,

Pass in a log visibility setting for the canister.

pub fn with_environment_variables<C, E>(self, environment_variables: C) -> Self
where E: Display, C: TryInto<Vec<EnvironmentVariable>, Error = E>,

Pass in environment variables for the canister.

pub fn build(self) -> Result<impl 'agent + AsyncCall<Value = ()>, AgentError>

Create an AsyncCall implementation that, when called, will update a canisters settings.

pub async fn call(self) -> Result<CallResponse<()>, AgentError>

Make a call. This is equivalent to the AsyncCall::call.

pub async fn call_and_wait(self) -> Result<(), AgentError>

Make a call. This is equivalent to the AsyncCall::call_and_wait.