[−][src]Enum ic_utils::call::Expiry
An expiry value. Either not specified (the default), a delay relative to the time the call is made, or a specific date time.
Variants
Unspecified. Will not try to override the Agent's value, which might itself have its own default value.
Delay(Duration)A duration that will be added to the system time when the call is made.
DateTime(SystemTime)A specific date and time to use for the expiry of the request.
Implementations
impl Expiry[src]
pub fn after(d: Duration) -> Self[src]
Create an expiry that happens after a duration.
pub fn at(dt: SystemTime) -> Self[src]
Set the expiry field to a specific date and time.