[−][src]Trait ic_utils::call::SyncCall
A type that implements synchronous calls (ie. 'query' calls).
Required methods
#[must_use]fn call<'async_trait>(
self
) -> Pin<Box<dyn Future<Output = Result<O, AgentError>> + Send + 'async_trait>> where
Self: 'async_trait,
self
) -> Pin<Box<dyn Future<Output = Result<O, AgentError>> + Send + 'async_trait>> where
Self: 'async_trait,
Execute the call, returning either the value returned by the canister, or an error returned by the Agent.
Implementors
impl<'agent, O> SyncCall<O> for SyncCaller<'agent> where
O: 'agent + for<'de> ArgumentDecoder<'de> + Send + Sync, [src]
O: 'agent + for<'de> ArgumentDecoder<'de> + Send + Sync,