Struct ic_utils::interfaces::wallet::CallForwarder[][src]

pub struct CallForwarder<'agent, 'canister: 'agent, Out> where
    Self: 'canister,
    Out: for<'de> ArgumentDecoder<'de> + Send + Sync
{ /* fields omitted */ }

Implementations

impl<'agent, 'canister: 'agent, Out> CallForwarder<'agent, 'canister, Out> where
    Out: for<'de> ArgumentDecoder<'de> + Send + Sync
[src]

pub fn with_arg<Argument>(self, arg: Argument) -> Self where
    Argument: CandidType + Sync + Send
[src]

Add an argument to the candid argument list. This requires Candid arguments, if there is a raw argument set (using [with_arg_raw]), this will fail.

pub fn with_arg_raw(self, arg: Vec<u8>) -> Self[src]

Replace the argument with raw argument bytes. This will overwrite the current argument set, so calling this method twice will discard the first argument.

pub fn build(self) -> Result<impl 'agent + AsyncCall<Out>, AgentError>[src]

pub async fn call(self) -> Result<RequestId, AgentError>[src]

pub async fn call_and_wait<W>(self, waiter: W) -> Result<Out, AgentError> where
    W: Waiter
[src]